"""
  File:        objects.py
  Author:      Petr `s3rvac` Zemek, s3rvac [at] seznam [dot] cz
  Date:        30.5.2007
  Description: Objects that can be placed on the simulation grid
"""

class Object:
	"""Abstract base class for all objects on the simulation grid"""

	# Object's number that is representing it
	objectNumber = -1;

	# Object color
	objectColor = 'black'

	def __init__(self):
		"""Constructor"""
		pass

	def getNumberRepresentation(self):
		"""Returns object's number that is representing it"""
		return self.__class__.objectNumber

	def getObjectColor(self):
		"""Returns object color (for GUI purposes)"""
		return self.__class__.objectColor

	def empty(self):
		"""Returns true if the selected object is "empty" (i.e. it's not a tree)"""
		raise NotImplementedError()

class ObjectEmpty(Object):
	"""Empty place"""

	# Object's number that is representing it
	objectNumber = 0;

	# Object color
	objectColor = 'yellow'

	def __init__(self):
		"""Constructor"""
		Object.__init__(self)
		pass

	def empty(self):
		"""Returns true if the selected object is "empty" (i.e. it's not a tree)"""
		return True

class ObjectTree(Object):
	"""Tree"""

	# Object's number that is representing it
	objectNumber = 1;
	objectNumberBurning = 2;

	# Object color
	objectColor = 'green'
	objectColorBurning = 'red'

	def __init__(self, probCatch, burning = False):
		"""Constructor

		probCatch - probability of a tree in a cell catching
		            fire if a tree in a neighboring cell is on fire
		"""
		Object.__init__(self)
		self.__probCatch = probCatch
		self.__burning = burning

	def getNumberRepresentation(self):
		"""Returns object's number that is representing it"""
		if self.isBurning():
			return self.__class__.objectNumberBurning
		else:
			return self.__class__.objectNumber

	def getObjectColor(self):
		"""Returns object color (for GUI purposes)"""
		if self.isBurning():
			return self.__class__.objectColorBurning
		else:
			return self.__class__.objectColor

	def isBurning(self):
		"""Returns true if the selected tree is burning"""
		return self.__burning

	def setBurning(self):
		"""Sets tree's the burning state (i.e. it's burning)"""
		self.__burning = True

	def empty(self):
		"""Returns true if the selected object is "empty" (i.e. it's not a tree)"""
		return False

	def getProbCatch(self):
		"""Returns tree probCatch probability"""
		return self.__probCatch

# End of file: objects.py
