"""
  File:        fexceptions.py
  Author:      Petr `s3rvac` Zemek, s3rvac [at] seznam [dot] cz
  Date:        28.5.2007
  Description: Exceptions that can be raised in the program
"""

class FException(Exception):
	"""Base exceptions class"""
	def __init__(self, errorMessage = ""):
		"""errorMessage - program error message"""
		self.errorMessage = errorMessage

	def getErrorMessage(self):
		"""Returns error message"""
		return self.errorMessage

	def __str__(self):
		return self.errorMessage

class OptionsException(FException):
	"""Option exceptions base class"""
	def __init__(self, errorMessage = ""):
		FException.__init__(self, errorMessage)

class OptionsExceptionMessageShowed(OptionsException):
	"""This exception will be thrown after the program help or version is shown"""
	pass

class OptionsExceptionOptionError(OptionsException):
	"""This exception will be thrown if there is some error in options"""
	pass

class InterfaceException(FException):
	"""Interface exceptions base class"""
	pass

class InterfaceExceptionInvalidAction(InterfaceException):
	"""This exception will be thrown if an user has selected wrong (invalid) action"""
	pass

class InterfaceExceptionBreakExecution(InterfaceException):
	"""This exception will be thrown if an user wants to break program execution"""
	pass

# End of file: fexceptions.py
