#!/usr/bin/python
"""
  File:        fire.py
  Author:      Petr `s3rvac` Zemek, s3rvac [at] seznam [dot] cz
  Date:        4.6.2007
  Description: Real-world example simulating spread of fire
               across a terrain, depending on humidity etc.
"""

import sys
import options
import messages
import errcodes
from cli import interface, actions
from core import Simulation
from fexceptions import *

def getLegalActionFromUser():
	"""Reads an action from the standard input and returns it as an action.
	If an user selects invalid action, it will keep asking for a valid one."""
	while 1:
		try:
			return interface.getActionFromUser()
		except InterfaceExceptionInvalidAction, e:
			messages.printErrorMessage(e.getErrorMessage())
		except InterfaceExceptionBreakExecution:
			return actions.EXIT

def main():
	"""Program main entry point"""
	try:
		continueSimulation = True
		options.analyzeOptions(sys.argv[1:])
		sim = Simulation.Simulation(options.options["areaSize"], options.options["probCatch"])
		if options.options["console"]:
			# Program will be running only in console
			interface.printSimulationGrid(sim)
			interface.showMenu()
			action = getLegalActionFromUser()
			while action != actions.EXIT:
				if action == actions.EXIT:
					sys.exit(errcodes.ERR_SUCCESS)
				elif action == actions.APPLYSPREAD:
					stateChanged = sim.applySpread()
					if not stateChanged:
						continueSimulation = False
						messages.printErrorMessage("There are no burning trees on the simulation grid.")
				elif action == actions.RESTARTSIMULATION:
					sim.restoreOriginalState()
					continueSimulation = True
				"""  # Not implemented yet
				elif action == actions.STARTSIMULATION:
					pass
				elif action == actions.STOPSIMULATION:
					pass
				"""
				if continueSimulation:
					interface.printSimulationGrid(sim)
				interface.showMenu()
				action = getLegalActionFromUser()
		else:
			# Show graphical user interface
			from gui import SimWin
			win = SimWin.SimWin(sim)
			win.show()
	except OptionsExceptionMessageShowed:
		sys.exit(errcodes.ERR_SUCCESS)
	except OptionsExceptionOptionError, e:
		messages.printErrorMessageWithHelp(e.getErrorMessage())
		sys.exit(errcodes.ERR_OPTIONS)
	except OptionsException, e:
		messages.printErrorMessage(e.getErrorMessage())
		sys.exit(errcodes.ERR_OPTIONS)
	except FException, e:
		messages.printErrorMessage(e.getErrorMessage())
		sys.exit(errcodes.ERR_APPLICATION)
	except Exception, e:
		messages.printErrorMessage(e.getErrorMessage())
		sys.exit(errcodes.ERR_STANDARD)
	except KeyboardInterrupt:
		sys.exit(errcodes.ERR_PROG_INTERUPTED)
	except:
		# This should never happen, but who knows...
		sys.stderr.write("Unknown error has occured\n")
		sys.exit(errcodes.ERR_UNKNOWN)
	sys.exit(errcodes.ERR_SUCCESS)

# Script start
if __name__ == "__main__":
	main()

# End of file: fire.py
