"""
  File:        messages.py
  Author:      Petr `s3rvac` Zemek, s3rvac [at] seznam [dot] cz
  Date:        28.5.2007
  Description: Various messages that are printed by the application
               like help, version etc.
"""

import sys
import common
import options

def printVersion():
	"""Prints program version and some additional data (license and author)"""
	print "%s %s" % (common.getProgramName(), common.getVersion())
	print "This is free software.  You may redistribute copies of it under the terms of\n" \
		"the GNU General Public License <http://www.gnu.org/licenses/gpl.html>.\n" \
		"There is NO WARRANTY, to the extent permitted by law.\n" \
		"\n" \
		"Written by Petr `s3rvac` Zemek, s3rvac [at] seznam [dot] cz, 2007"

def printHelp():
	"""Prints program help"""
	print "Usage: %s [OPTIONS]..." % common.getProgramName()
	print "  -a, --area-size=N       Area size (%s - %s)" \
		% (options.getMinAreaSize(), options.getMaxAreaSize())
	print "  -c, --prob-catch=N      Probability of a tree catching fire (%s - %s)" \
		% (options.getMinProbCatch(), options.getMaxProbCatch())
	print "  -l, --prob-lightning=N  Probability that the tree is struck by lightning. (%s - %s)" \
		% (options.getMinProbLightning(), options.getMaxProbLightning())
	print "  -t, --prob-tree=N       Probability of a grid site being occupied by a tree initially (%s - %s)" \
		% (options.getMinProbTree(), options.getMaxProbTree())
	print "  -b, --prob-burning=N    Probability that a tree is initially burning (%s - %s)" \
		% (options.getMinProbBurning(), options.getMaxProbBurning())
	print "  -i, --interval=N        Time interval between two simulation steps in microseconds (%s - %s)" \
		% (options.getMinInterval(), options.getMaxInterval())
	print "  -n, --neighbourhood=N   Neighbourhood that will be used when applying spread %s" \
		% str(options.getPossibleNeighbourhoods())
	print "  -c, --console           Application will run in a console (without graphical interface)"
	print "      --help              Display this help and exit"
	print "      --version           Output version information and exit"
	#print "Default configuration is:"
	#print "  %s -a 30 -c 0.5 -l 0.0 -t 1.0 -b 0.0 -i 200 -n 4" % common.getProgramName()

def printErrorMessage(errorMessage):
	"""Prints selected error message
	errorMessage - error message"""
	sys.stderr.write("%s: %s\n" % (common.getProgramName(), errorMessage))

def printErrorMessageWithHelp(errorMessage):
	"""Prints selected error message with "for more information..." message after it
	errorMessage - errror message"""
	sys.stderr.write("%s: %s\n" % (common.getProgramName(), errorMessage))
	sys.stderr.write("Try `%s --help' for more information.\n" % common.getProgramName())

# End of file: messages.py
